@@ -1,9 +1,10 @@
 #' @rdname rfPermute
-#' @usage \method{rfPermute}{formula}(formula, data = NULL, \dots, subset, na.action = na.fail, nrep = 100)
+#' @usage \method{rfPermute}{formula}(formula, data = NULL, \dots, subset, na.action = na.fail, nrep = 100, num.cores = options("mc.cores"))
 
-rfPermute.formula <- function(formula, data = NULL, ..., subset, na.action = na.fail, nrep = 100) {
+rfPermute.formula <- function(formula, data = NULL, ..., subset, na.action = na.fail, nrep = 100, num.cores = options("mc.cores")) {
   # Takes same arguments as 'randomForest.formula', plus
   #   'nrep': number of permutation replicates
+  #   'num.cores' : number of cores to use
   #
   # Returns 'randomForest' object with:
   #   'null.dist' : 3 element named list with null distribution matrices
@@ -24,7 +25,7 @@ rfPermute.formula <- function(formula, data = NULL, ..., subset, na.action = na.
   if (is.matrix(eval(m$data, parent.frame()))) m$data <- as.data.frame(data)
   m$... <- NULL
   m$nrep <- NULL
-  m$clust.opts <- NULL
+  m$num.cores <- NULL
   m$na.action <- na.action
   m[[1]] <- as.name("model.frame")
   m <- eval(m, parent.frame())
@@ -51,7 +52,7 @@ rfPermute.formula <- function(formula, data = NULL, ..., subset, na.action = na.
   rf.call[[1]] <- as.name("randomForest")
   rf$call <- rf.call
   rf$call$nrep <- NULL
-  rf$call$clust.opts <- NULL
+  rf$call$num.cores <- NULL
   rf$terms <- Terms
   if (!is.null(attr(m, "na.action"))) rf$na.action <- attr(m, "na.action")
   
